# mallard-ducktype
Parser for the lightweight Ducktype syntax for Mallard

## Install Ducktype

Ducktype is Python-3-only, so to build and install:

```
python3 setup.py build
sudo python3 setup.py install
```

Or to get the latest version uploaded to pypi:

```
virtualenv --python=python3 venv
source venv/bin/activate
pip-python3 install mallard-ducktype
```
